@@ -52,7 +52,7 @@ mod macros;
 pub use types::{RawToken, Token, TokenIter, SourceMap, SourceMapIndex,
                 SourceMapSection, SourceMapSectionIter};
 pub use errors::{Result, Error};
-pub use decoder::{decode, decode_data_url, DecodedMap};
+pub use decoder::{decode, decode_slice, decode_data_url, DecodedMap};
 pub use detector::{SourceMapRef, locate_sourcemap_reference};
 
 mod errors;
